---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behaviour:
1. Paste python code that was run to produce the error
2. Paste the error message(s)

**Expected behaviour**
A clear and concise description of what you expected to happen.

**System and python details (please complete):**
 - OS: (e.g. output of `cat /etc/*-release` on Linux)
 - Python version (e.g. output of `python --version`)
 - swiftgalaxy version, and versions of dependencies (e.g. output of `pip freeze`)

**Additional context**
Add any other context about the problem here.
